@@ -725,7 +725,8 @@ Image::Indexed **Image::Indexed::separate() {
 
   ret[nncols]=(Indexed*)NULLP;
   to8();
-  for (curcol=0; curcol<=ncols1; curcol++) {
+  curcol=0;
+  do {
     if (transp==(signed int)curcol) continue;
     curimg[0]=new Indexed(wd, ht, /*ncols:*/2, /*bpc:*/1);
     memcpy(curimg[0]->headp, headp+3*curcol, 3); /* copy the color value */
@@ -743,7 +744,7 @@ Image::Indexed **Image::Indexed::separate() {
       if (0!=(wdcpp&7)) p+=(wdcpp&7)-8; /* negative */
     }
     curimg++;
-  }
+  } while (curcol++<ncols1); /* Dat: OK with curcol:255->0 rounding */
   assert(curimg==ret+nncols);
   return ret;
 }
@@ -1477,7 +1478,8 @@ bool Image::SampledInfo::setSampleFormat(sf_t sf_, bool WarningOK, bool TryOnly,
       iimg->packPal();
     }
     /* printf("gett=%d\n", PTS_dynamic_cast(Indexed*,img)->getTransp()); */
-    assert(PTS_dynamic_cast(Indexed*,img)->getTransp()==-1 || PTS_dynamic_cast(Indexed*,img)->getTransp()+0U<1U);
+    /* vvv BUGFIX: <1U -> <2U */
+    assert(PTS_dynamic_cast(Indexed*,img)->getTransp()==-1 || PTS_dynamic_cast(Indexed*,img)->getTransp()+0U<2U);
     /* ^^^ color 0 is opaque, color 1 is transparent, thanks to
      * img->packPal() called in SampleInfo() -- but setTranspc may have changed this
      */
